@@ -1,4 +1,5 @@
-/* Copyright (c) 1999, 2000, 2001, 2002 SuSE GmbH Nuernberg, Germany
+/* Copyright (c) 2003 SuSE Linux AG, Germany
+ * Copyright (c) 1999, 2000, 2001, 2002 SuSE GmbH Nuernberg, Germany
  * Author: Thorsten Kukuk <kukuk@suse.de>
  *
  * This version based on the login program from util-linux 2.9s, but
@@ -75,6 +76,7 @@
 #define PAM_FAIL_CHECK if (retcode != PAM_SUCCESS) { \
        fprintf (stderr, "\n%s\n", pam_strerror (pamh, retcode)); \
        syslog (LOG_ERR, "%s", pam_strerror (pamh, retcode)); \
+       sleep (getdef_num ("FAIL_DELAY", 1)); \
        pam_end (pamh, retcode); \
        exit (1); \
    }
@@ -205,7 +207,7 @@ timedout (int sig __attribute__ ((unused)))
    connection. I believe login should open the line in the non-blocking mode
    leaving the decision to make a connection to getty (where it actually
    belongs). */
-static inline void
+static void
 opentty (const char *tty)
 {
   int i, flags;
@@ -263,7 +265,7 @@ check_ttyname (char *ttyn)
 
 /* true if the filedescriptor fd is a console tty, very Linux specific */
 /* XXX Does this work with serial console ?? (kukuk@suse.de) */
-static inline int
+static int
 consoletty (int fd)
 {
   struct stat stb;
@@ -367,7 +369,7 @@ dolastlog (int quiet, uid_t uid, const char *tty, const char *hostname)
 }
 
 /* Find out which TERM variable we need to set for this terminal. */
-static inline char *
+static char *
 ttytype (const char *line)
 {
   FILE *fp;
